@@ -3,7 +3,7 @@ package RPi::WiringPi::LCD;
 use strict;
 use warnings;
 
-our $VERSION = '1.00';
+our $VERSION = '1.01';
 
 use parent 'WiringPi::API';
 use RPi::WiringPi::Constant qw(:all);
@@ -86,10 +86,9 @@ pins
 
 =head1 SYNOPSIS
 
-    use RPi::WiringPi
+    use RPi::WiringPi::LCD;
 
-    my $pi = RPi::WiringPi->new;
-    my $lcd = $pi->lcd;
+    my $lcd = RPi::WiringPi::LCD->new;
 
     my %lcd_args = (
         rows  => 2,     # number of display rows, 2 or 4
@@ -123,7 +122,9 @@ pins
 =head1 DESCRIPTION
 
 This module acts as an interface to typical 2 or 4 row, 16 or 20 column LCD
-screens when connected to a Raspberry Pi.
+screens when connected to a Raspberry Pi. It is best used through a
+L<RPi::WiringPi> object.
+
 
 =head1 METHODS
 
@@ -140,8 +141,8 @@ so DON'T change it.
 Parameters:
 
     %args = (
-        rows => $num,       # number of rows. eg: 16 or 20
-        cols => $num,       # number of columns. eg: 2 or 4
+        rows => $num,       # number of rows. eg: 2 or 4
+        cols => $num,       # number of columns. eg: 16 or 20
         bits => 4|8,        # width of the interface (4 or 8)
         rs => $pin_num,     # pin number of the LCD's RS pin
         strb => $pin_num,   # pin number of the LCD's strobe (E) pin
